@@ -5,7 +5,8 @@ from enum import Enum
 from random import choice
 
 import typer
-from psycopg import connect, extras
+from psycopg import connect
+from psycopg.rows import dict_row
 from pymongo import MongoClient
 from rich.console import Console
 
@@ -87,13 +88,13 @@ def validate_lims(
 ) -> None:
     client = MongoClient(db_address)
     conn = connect(lims_address)
-    with conn.cursor(cursor_factory=extras.RealDictCursor) as cursor:
+    with conn.cursor(row_factory=dict_row) as cursor:
         validated = validate_lims_upload(
             client,
             cursor,
             lims_id,
         )
-    console.print(from_AssetValidationResult(validation) for validation in validations)
+    console.print(from_AssetValidationResult(validation) for validation in validated)
 
 
 @app.command()
